@@ -12,12 +12,15 @@ from codalab.objects.metadata_spec import MetadataSpec
 
 class DerivedBundle(NamedBundle):
     METADATA_SPECS = list(NamedBundle.METADATA_SPECS)  # type: List
-    # Don't format specs
-    # fmt: off
     METADATA_SPECS.append(
-        MetadataSpec('allow_failed_dependencies', bool, 'Whether to allow this bundle to have failed or killed dependencies (allow_failed_dependencies).', default=False,)
+        MetadataSpec(
+            'allow_failed_dependencies',
+            bool,
+            'Whether to allow this bundle to have failed or killed dependencies (allow_failed_dependencies).',
+            default=False,
+            lock_after_start=True,
+        )
     )
-    # fmt: on
 
     @classmethod
     def construct(cls, targets, command, metadata, owner_id, uuid, data_hash, state):
