@@ -1,13 +1,12 @@
-'''
+"""
 ProgramBundle is a Bundle type that inherits from UploadedBundle and adds a
 new metadata key, architectures.
 
 When a RunBundle is constructed, its program_target must be in a ProgramBundle.
-'''
+"""
 from typing import List
 
 from codalab.bundles.uploaded_bundle import UploadedBundle
-from codalab.objects.metadata_spec import MetadataSpec
 
 
 # This class will eventually be deprecated.
