@@ -372,6 +372,7 @@ def get_bundle_state_details(bundle):
     """
     metadata = bundle.get('metadata', {})
     run_status = metadata.get('run_status')
+    staged_status = metadata.get('staged_status')
     type = bundle.get('bundle_type')
     state = bundle.get('state')
     state_details_by_type = {
@@ -389,7 +390,6 @@ def get_bundle_state_details(bundle):
         },
         'run': {
             'created': 'Bundle has been created but its contents have not been populated yet.',
-            'staged': 'Bundle’s dependencies are all ready. Waiting for the bundle to be assigned to a worker to be run.',
             'starting': 'Bundle has been assigned to a worker. Waiting for worker to start the bundle.',
             'finalizing': 'Bundle command has finished executing, cleaning up on the worker.',
             'ready': 'Bundle command has finished executing successfully, and results have been uploaded to the server.',
@@ -399,10 +399,13 @@ def get_bundle_state_details(bundle):
         },
     }
 
-    # We can remove the defensive checks below once program bundles are converted to dataset bundles.
-    # Related Issue: https://github.com/codalab/codalab-worksheets/issues/4235
-    state_details = state_details_by_type.get(type, {}).get(state, '')
+    if state == 'staged':
+        return staged_status
 
     if state == 'preparing' or state == 'running':
         return run_status
+
+    # We can remove the defensive checks below once program bundles are converted to dataset bundles.
+    # Related Issue: https://github.com/codalab/codalab-worksheets/issues/4235
+    state_details = state_details_by_type.get(type, {}).get(state, '')
     return state_details
