@@ -23,7 +23,6 @@ class User(ORMObject):
         'date_joined',
         'has_access',
         'is_verified',
-        'is_superuser',
         'password',
         'time_quota',
         'parallel_run_quota',
@@ -140,7 +139,6 @@ PUBLIC_USER = User(
         "date_joined": None,
         "has_access": False,
         "is_verified": True,
-        "is_superuser": False,
         "password": None,
         "time_quota": 0,
         "parallel_run_quota": 0,
