@@ -24,6 +24,8 @@ from codalab.worker.docker_utils import DockerRuntime, DockerException
 from codalab.worker.dependency_manager import DependencyManager
 from codalab.worker.docker_image_manager import DockerImageManager
 from codalab.worker.singularity_image_manager import SingularityImageManager
+from codalab.worker.noop_image_manager import NoOpImageManager
+from codalab.worker.runtime.kubernetes_runtime import KubernetesRuntime
 
 logger = logging.getLogger(__name__)
 
@@ -43,6 +45,12 @@ def parse_args():
         help='URL of the CodaLab server, in the format '
         '<http|https>://<hostname>[:<port>] (e.g., https://worksheets.codalab.org)',
     )
+    parser.add_argument(
+        '--ws-server',
+        default=None,
+        help='URL of the CodaLab websocket server, in the format '
+        '<ws|wss>://<hostname>[:<port>] (e.g., wss://worksheets.codalab.org/ws)',
+    )
     parser.add_argument(
         '--work-dir',
         default='codalab-worker-scratch',
@@ -125,9 +133,13 @@ def parse_args():
     )
     parser.add_argument(
         '--bundle-runtime',
-        choices=[BundleRuntime.DOCKER.value, BundleRuntime.SINGULARITY.value,],
+        choices=[
+            BundleRuntime.DOCKER.value,
+            BundleRuntime.KUBERNETES.value,
+            BundleRuntime.SINGULARITY.value,
+        ],
         default=BundleRuntime.DOCKER.value,
-        help='The runtime through which the worker will run bundles. The options are docker (default) or singularity',
+        help='The runtime through which the worker will run bundles. The options are docker (default), kubernetes, or singularity',
     )
     parser.add_argument(
         '--idle-seconds',
@@ -195,6 +207,21 @@ def parse_args():
     parser.add_argument(
         '--preemptible', action='store_true', help='Whether the worker is preemptible.',
     )
+    parser.add_argument(
+        '--kubernetes-cluster-host',
+        type=str,
+        help='Host address of the Kubernetes cluster. Only applicable if --bundle-runtime is set to kubernetes.',
+    )
+    parser.add_argument(
+        '--kubernetes-auth-token',
+        type=str,
+        help='Kubernetes cluster authorization token. Only applicable if --bundle-runtime is set to kubernetes.',
+    )
+    parser.add_argument(
+        '--kubernetes-cert-path',
+        type=str,
+        help='Path to the SSL cert for the Kubernetes cluster. Only applicable if --bundle-runtime is set to kubernetes.',
+    )
     return parser.parse_args()
 
 
@@ -291,6 +318,15 @@ def main():
         # todo workers with singularity don't work because this is set to none -- handle this
         bundle_runtime_class = None
         docker_runtime = None
+    elif args.bundle_runtime == BundleRuntime.KUBERNETES.value:
+        image_manager = NoOpImageManager()
+        bundle_runtime_class = KubernetesRuntime(
+            args.work_dir,
+            args.kubernetes_auth_token,
+            args.kubernetes_cluster_host,
+            args.kubernetes_cert_path,
+        )
+        docker_runtime = None
     else:
         image_manager = DockerImageManager(
             os.path.join(args.work_dir, 'images-state.json'),
@@ -307,6 +343,12 @@ def main():
         logger.info('%s doesn\'t exist, creating.', local_bundles_dir)
         os.makedirs(local_bundles_dir, 0o770)
 
+    if not args.ws_server:
+        # Set default
+        args.ws_server = (
+            args.server.replace("https://", "wss://").replace("http://", "ws://") + "/ws"
+        )
+
     worker = Worker(
         image_manager,
         dependency_manager,
@@ -326,8 +368,9 @@ def main():
         args.checkin_frequency_seconds,
         bundle_service,
         args.shared_file_system,
-        args.tag_exclusive,
+        args.tag_exclusive if args.tag else False,
         args.group,
+        ws_server=args.ws_server,
         docker_runtime=docker_runtime,
         docker_network_prefix=args.network_prefix,
         pass_down_termination=args.pass_down_termination,
@@ -335,7 +378,7 @@ def main():
         exit_on_exception=args.exit_on_exception,
         shared_memory_size_gb=args.shared_memory_size_gb,
         preemptible=args.preemptible,
-        bundle_runtime=DockerRuntime(),
+        bundle_runtime=bundle_runtime_class,
     )
 
     # Register a signal handler to ensure safe shutdown.
@@ -387,9 +430,6 @@ def parse_gpuset_args(arg):
     """
     Parse given arg into a set of strings representing gpu UUIDs
     By default, we will try to start a Docker container with nvidia-smi to get the GPUs.
-    If we get an exception that the Docker socket does not exist, which will be the case
-    on Singularity workers, because they do not have root access, and therefore, access to
-    the Docker socket, we should try to get the GPUs with Singularity.
 
     Arguments:
         arg: comma separated string of ints, or "ALL" representing all gpus
